@@ -7,18 +7,18 @@ fn base() {
     let last = clock_source::now();
     thread::sleep(Duration::from_millis(100));
     let now = clock_source::now();
-    println!("{:?}", last.as_millis());
-    println!("{:?}", now.as_millis());
+    println!("{:?}", last);
+    println!("{:?}", now);
 
-    assert!(now - last > Duration::from_millis(100))
+    assert!(now - last > Duration::from_millis(100).as_nanos() as u64)
 }
 
 #[cfg(not(feature = "std"))]
 #[test]
 fn set() {
-    static SOURCE: fn() -> Duration = || Duration::from_secs(1);
+    static SOURCE: fn() -> u64 = || 1;
     clock_source::register_clock_source!(SOURCE);
-    assert_eq!(clock_source::now(), Duration::from_secs(1));
+    assert_eq!(clock_source::now(), 1);
     thread::sleep(Duration::from_millis(100));
-    assert_eq!(clock_source::now(), Duration::from_secs(1));
+    assert_eq!(clock_source::now(), 1);
 }
